@@ -55,7 +55,7 @@
 #'  each dashboard component in a navigable storyboard frame. When a storyboard
 #'  layout is used the \code{orientation} and \code{vertical_layout} arguments
 #'  are ignored. When creating a dashbaord with multiple pages you should apply
-#'  the `{.storyboard}` attribute to individual pages rather than using the
+#'  the \code{\{.storyboard\}} attribute to individual pages rather than using the
 #'  global \code{storyboard} option.
 #'
 #'@param theme One of the following:
@@ -317,7 +317,7 @@ flex_dashboard <- function(fig_width = 6.0,
         if (fill_page) readLines(resource("fillpage.css")),
         '</style>'
       )
-      dashboardCssFile <- tempfile(fileext = "html")
+      dashboardCssFile <- tempfile(fileext = ".html")
       writeLines(dashboardCss, dashboardCssFile)
       includes$in_header <- c(includes$in_header, dashboardCssFile)
 
